@@ -206,7 +206,7 @@ private:
         KSharedConfig::Ptr config = KSharedConfig::openConfig();
         KConfigGroup group = config->group(mTreeStateConfig);
         treeStateSaver.setView(mTreeView);
-        treeStateSaver.setSelectionModel(0); // we only save expand state
+        treeStateSaver.setSelectionModel(nullptr); // we only save expand state
         treeStateSaver.saveState(group);
     }
 
@@ -289,7 +289,7 @@ public:
         return score;
     }
 
-    bool lessThan(const QModelIndex &left, const QModelIndex &right) const Q_DECL_OVERRIDE
+    bool lessThan(const QModelIndex &left, const QModelIndex &right) const override
     {
         const int leftScore = score(left);
         const int rightScore = score(right);
@@ -310,7 +310,7 @@ public:
     {
     }
 
-    QVariant data(const QModelIndex &index, int role) const Q_DECL_OVERRIDE
+    QVariant data(const QModelIndex &index, int role) const override
     {
         if (!index.isValid()) {
             return QVariant();
@@ -342,7 +342,7 @@ public:
         return QSortFilterProxyModel::data(index, role);
     }
 
-    Qt::ItemFlags flags(const QModelIndex &index) const Q_DECL_OVERRIDE
+    Qt::ItemFlags flags(const QModelIndex &index) const override
     {
         return Qt::ItemIsSelectable | QSortFilterProxyModel::flags(index);
     }
@@ -361,7 +361,7 @@ public:
     }
 
 protected:
-    bool filterAcceptsRow(int row, const QModelIndex &sourceParent) const Q_DECL_OVERRIDE
+    bool filterAcceptsRow(int row, const QModelIndex &sourceParent) const override
     {
         const QModelIndex sourceIndex = sourceModel()->index(row, 0, sourceParent);
         Q_ASSERT(sourceIndex.isValid());
@@ -386,7 +386,7 @@ public:
 
 protected:
 
-    QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const Q_DECL_OVERRIDE
+    QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const override
     {
         if (role == EnabledRole) {
             Akonadi::Collection col = index.data(Akonadi::EntityTreeModel::CollectionRole).value<Akonadi::Collection>();
@@ -421,7 +421,7 @@ protected:
         return true;
     }
 
-    QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const Q_DECL_OVERRIDE
+    QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const override
     {
         if (role == Qt::CheckStateRole) {
             if (sourceModel()->hasChildren(mapToSource(index)) && index.data(NodeTypeRole).toInt() == PersonNodeRole) {
@@ -466,7 +466,7 @@ protected:
         }
     }
 
-    bool setData(const QModelIndex &index, const QVariant &value, int role = Qt::EditRole) Q_DECL_OVERRIDE {
+    bool setData(const QModelIndex &index, const QVariant &value, int role = Qt::EditRole) override {
         if (role == Qt::CheckStateRole)
         {
             if (sourceModel()->hasChildren(mapToSource(index)) && index.data(NodeTypeRole).toInt() == PersonNodeRole) {
@@ -507,7 +507,6 @@ AkonadiCollectionView::AkonadiCollectionView(CalendarView *view, bool hasContext
       mAssignColor(nullptr),
       mDisableColor(nullptr),
       mDefaultCalendar(nullptr),
-      mEnableAction(nullptr),
       mServerSideSubscription(nullptr),
       mNotSendAddRemoveSignal(false),
       mWasDefaultCalendar(false),
@@ -633,7 +632,7 @@ AkonadiCollectionView::AkonadiCollectionView(CalendarView *view, bool hasContext
                         << Akonadi::StandardActionManager::CopyCollectionToMenu
                         << Akonadi::StandardActionManager::MoveCollectionToMenu;
 
-        Q_FOREACH (Akonadi::StandardActionManager::Type standardAction, standardActions) {
+        for (Akonadi::StandardActionManager::Type standardAction : qAsConst(standardActions)) {
             mActionManager->createAction(standardAction);
         }
 
@@ -644,7 +643,7 @@ AkonadiCollectionView::AkonadiCollectionView(CalendarView *view, bool hasContext
                         << Akonadi::StandardCalendarActionManager::CreateJournal
                         << Akonadi::StandardCalendarActionManager::EditIncidence;
 
-        Q_FOREACH (Akonadi::StandardCalendarActionManager::Type calendarAction, calendarActions) {
+        for (Akonadi::StandardCalendarActionManager::Type calendarAction : qAsConst(calendarActions)) {
             mActionManager->createAction(calendarAction);
         }
 
@@ -690,16 +689,6 @@ AkonadiCollectionView::AkonadiCollectionView(CalendarView *view, bool hasContext
         xmlclient->actionCollection()->addAction(QStringLiteral("set_standard_calendar"),
                 mDefaultCalendar);
 
-        //Disable a calendar or remove a referenced calendar
-        QAction *disableAction = xmlclient->actionCollection()->addAction(QStringLiteral("collection_disable"), this, &AkonadiCollectionView::edit_disable);
-        disableAction->setText(i18n("Remove from list"));
-        disableAction->setIcon(QIcon::fromTheme(QStringLiteral("list-remove")));
-
-        //Enable (subscribe) to a calendar.
-        mEnableAction = xmlclient->actionCollection()->addAction(QStringLiteral("collection_enable"), this, &AkonadiCollectionView::edit_enable);
-        mEnableAction->setText(i18n("Add to list permanently"));
-        mEnableAction->setIcon(QIcon::fromTheme(QStringLiteral("bookmarks")));
-
         mServerSideSubscription = new QAction(QIcon::fromTheme(QStringLiteral("folder-bookmarks")), i18n("Serverside Subscription..."), this);
         xmlclient->actionCollection()->addAction(QStringLiteral("serverside_subscription"), mServerSideSubscription);
         connect(mServerSideSubscription, &QAction::triggered, this, &AkonadiCollectionView::slotServerSideSubscription);
@@ -852,11 +841,6 @@ void AkonadiCollectionView::updateMenu()
                                          collection.rights() & Akonadi::Collection::CanCreateItem);
             disableStuff = false;
         }
-        if (collection.isValid() && collection.shouldList(Akonadi::Collection::ListDisplay)) {
-            mEnableAction->setEnabled(false);
-        } else {
-            mEnableAction->setEnabled(true);
-        }
         bool isOnline;
         mServerSideSubscription->setEnabled(PimCommon::MailUtil::isImapFolder(collection, isOnline));
     } else {
@@ -1035,33 +1019,6 @@ Akonadi::EntityTreeModel *AkonadiCollectionView::entityTreeModel() const
     return nullptr;
 }
 
-void AkonadiCollectionView::edit_disable()
-{
-#if 0
-    Akonadi::Collection col = mCollectionView->currentIndex().data(Akonadi::EntityTreeModel::CollectionRole).value<Akonadi::Collection>();
-    if (col.isValid()) {
-        mController->setCollectionState(col, Controller::Disabled);
-    }
-#endif
-    const QVariant var = mCollectionView->currentIndex().data(PersonRole);
-    if (var.isValid()) {
-        mController->removePerson(var.value<KPIM::Person>());
-    }
-}
-
-void AkonadiCollectionView::edit_enable()
-{
-    Akonadi::Collection col = mCollectionView->currentIndex().data(Akonadi::EntityTreeModel::CollectionRole).value<Akonadi::Collection>();
-    qCDebug(KORGANIZER_LOG) << col.name();
-    if (col.isValid()) {
-        mController->setCollectionState(col, Controller::Enabled);
-    }
-    const QVariant var = mCollectionView->currentIndex().data(PersonRole);
-    if (var.isValid()) {
-        mController->addPerson(var.value<KPIM::Person>());
-    }
-}
-
 void AkonadiCollectionView::onAction(const QModelIndex &index, int a)
 {
     const StyledCalendarDelegate::Action action = static_cast<StyledCalendarDelegate::Action>(a);
